pub struct ShipmentItem {
Show 13 fields pub seller_sku: Option<String>, pub order_item_id: Option<String>, pub order_adjustment_item_id: Option<String>, pub quantity_shipped: Option<i32>, pub item_charge_list: Option<Vec<ChargeComponent>>, pub item_charge_adjustment_list: Option<Vec<ChargeComponent>>, pub item_fee_list: Option<Vec<FeeComponent>>, pub item_fee_adjustment_list: Option<Vec<FeeComponent>>, pub item_tax_withheld_list: Option<Vec<TaxWithheldComponent>>, pub promotion_list: Option<Vec<Promotion>>, pub promotion_adjustment_list: Option<Vec<Promotion>>, pub cost_of_points_granted: Option<Box<Currency>>, pub cost_of_points_returned: Option<Box<Currency>>,
}
ShipmentItem : An item of a shipment, refund, guarantee claim, or chargeback.

Fields

seller_sku: Option<String>

The seller SKU of the item. The seller SKU is qualified by the seller’s seller ID, which is included with every call to the Selling Partner API.

order_item_id: Option<String>

An Amazon-defined order item identifier.

order_adjustment_item_id: Option<String>

An Amazon-defined order adjustment identifier defined for refunds, guarantee claims, and chargeback events.

quantity_shipped: Option<i32>

The number of items shipped.

item_charge_list: Option<Vec<ChargeComponent>>

A list of charge information on the seller’s account.

item_charge_adjustment_list: Option<Vec<ChargeComponent>>

A list of charge information on the seller’s account.

item_fee_list: Option<Vec<FeeComponent>>

A list of fee component information.

item_fee_adjustment_list: Option<Vec<FeeComponent>>

A list of fee component information.

item_tax_withheld_list: Option<Vec<TaxWithheldComponent>>

A list of information about taxes withheld.

promotion_list: Option<Vec<Promotion>>

A list of promotions.

promotion_adjustment_list: Option<Vec<Promotion>>

A list of promotions.

cost_of_points_granted: Option<Box<Currency>>cost_of_points_returned: Option<Box<Currency>>

Implementations

An item of a shipment, refund, guarantee claim, or chargeback.